src/eric7/DocumentationTools/IndexGenerator.py

branch
eric7
changeset 10423
299802979277
parent 10373
093dcebe5ecb
child 10439
21c28b0f9e41
diff -r e28b89693f37 -r 299802979277 src/eric7/DocumentationTools/IndexGenerator.py
--- a/src/eric7/DocumentationTools/IndexGenerator.py	Tue Dec 19 11:04:03 2023 +0100
+++ b/src/eric7/DocumentationTools/IndexGenerator.py	Tue Dec 19 19:57:08 2023 +0100
@@ -39,12 +39,15 @@
         """
         Public method to remember a documentation file.
 
-        @param file The filename to be remembered. (string)
-        @param moduleDocument The ModuleDocument object containing the
-            information for the file.
-        @param basename The basename of the file hierarchy to be documented.
-            The basename is stripped off the filename if it starts with
-            the basename.
+        @param file The filename to be remembered.
+        @type str
+        @param moduleDocument module documentation object containing the
+            information for the file
+        @type ModuleDocument
+        @param basename base name of the file hierarchy to be documented.
+            The base name is stripped off the filename if it starts with
+            the base name.
+        @type str
         """
         self.remembered = True
         if basename:
@@ -84,10 +87,14 @@
         """
         Private method to generate an index file for a package.
 
-        @param packagename The name of the package. (string)
-        @param package A dictionary with information about the package.
-        @param newline newline character to be used (string)
-        @return The name of the generated index file.
+        @param packagename The name of the package.
+        @type str
+        @param package dictionary with information about the package
+        @type dict
+        @param newline newline character to be used
+        @type str
+        @return name of the generated index file
+        @rtype str
         """
         if packagename == "00index":
             f = os.path.join(self.outputDir, "index")
@@ -170,10 +177,12 @@
         """
         Public method to generate all index files.
 
-        @param basename The basename of the file hierarchy to be documented.
-            The basename is stripped off the filename if it starts with
-            the basename.
-        @param newline newline character to be used (string)
+        @param basename base name of the file hierarchy to be documented.
+            The base name is stripped off the filename if it starts with
+            the base name.
+        @type str
+        @param newline newline character to be used
+        @type str
         """
         if not self.remembered:
             sys.stderr.write("No index to generate.\n")

eric ide

mercurial